#
# spec file for package perl-ExtUtils-Depends
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name ExtUtils-Depends
Name:           perl-ExtUtils-Depends
Version:        0.8001
Release:        1.10
#Upstream: SUSE-Public-Domain
Summary:        Easily build XS extensions that depend on XS extensions
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/X/XA/XAOC/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.44
Requires:       perl(ExtUtils::MakeMaker) >= 7.44
%{perl_requires}

%description
This module tries to make it easy to build Perl extensions that use
functions and typemaps provided by other perl extensions. This means that a
perl extension is treated like a shared library that provides also a C and
an XS interface besides the perl one.

This works as long as the base extension is loaded with the RTLD_GLOBAL
flag (usually done with a

	sub dl_load_flags {0x01}

in the main .pm file) if you need to use functions defined in the module.

The basic scheme of operation is to collect information about a module in
the instance, and then store that data in the Perl library where it may be
retrieved later. The object can also reformat this information into the
data structures required by ExtUtils::MakeMaker's WriteMakefile function.

For information on how to make your module fit into this scheme, see
"hashref = ExtUtils::Depends::load (name)".

When creating a new Depends object, you give it a name, which is the name
of the module you are building. You can also specify the names of modules
on which this module depends. These dependencies will be loaded
automatically, and their typemaps, header files, etc merged with your new
object's stuff. When you store the data for your object, the list of
dependencies are stored with it, so that another module depending on your
needn't know on exactly which modules yours depends.

For example:

  Gtk2 depends on Glib

  Gnome2::Canvas depends on Gtk2

  ExtUtils::Depends->new ('Gnome2::Canvas', 'Gtk2');
     this command automatically brings in all the stuff needed
     for Glib, since Gtk2 depends on it.

When the configuration information is saved, it also includes a class
method called 'Inline', inheritable by your module. This allows you in your
module to simply say at the top:

  package Mymod;
  use parent 'Mymod::Install::Files'; # to inherit 'Inline' method

And users of 'Mymod' who want to write inline code (using Inline) will
simply be able to write:

  use Inline with => 'Mymod';

And all the necessary header files, defines, and libraries will be added
for them.

The 'Mymod::Install::Files' will also implement a 'deps' method, which will
return a list of any modules that 'Mymod' depends on - you will not
normally need to use this:

  require Mymod::Install::Files;
  @deps = Mymod::Install::Files->deps;

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Mon May 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.8001
  see /usr/share/doc/packages/perl-ExtUtils-Depends/Changes
  0.8001
  - Remove hack (cf https://rt.cpan.org/Ticket/Display.html?id=45224)
    The hijacking of EUMM's `static_lib` method is now obsolete, as well as
    causing problems.
  - Also added a couple of code tidy-ups
* Wed Apr 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.8000
  see /usr/share/doc/packages/perl-ExtUtils-Depends/Changes
  0.8000
  - Bump version so https://metacpan.org/pod/ExtUtils::Depends shows the
    correct _ExtUtils::Depends_ module
  - Quote directories with spaces
* Wed Dec  2 2015 coolo@suse.com
- updated to 0.405
  see /usr/share/doc/packages/perl-ExtUtils-Depends/Changes
  0.405
  - Remove MYMETA.* from MANIFEST file; closes autogenerated RT ticket
    [#108554]
* Tue Feb  3 2015 coolo@suse.com
- updated to 0.404
  - Depends.pm: sort deps in save_config() and get_makefile_vars(); patch
    submitted by Debian's reproducible build team for RT#101602
  - Use / to make ::load filename, not File::Spec - perldoc -f require
  0.403
  - Avoid using Test::More::done_testing() for to support building
    out-of-the-box on older perls.
  0.402 Sat Oct 18 18:06:19 EEST 2014
  - Set Data::Dumper::Sortkeys = 1 in ExtUtils::Depends->save_config();
    patch submitted by Niko Tyni of the Debian Perl Group; fixes RT#99260
* Fri Sep 19 2014 coolo@suse.com
- updated to 0.401
  - Add README changes created by 'make dist' from the POD
  - Rename test modules
  - Test old/new schemes with .pm files
  - Move old/new scheme tests from middle of other stuff to end
  - Rename test packages to 8.3 unique
  0.400 Sun Aug 10 13:58:24 CEST 2014
  - In addition to the package variables $inc, $libs and @typemaps, write an
    'Inline' method to <package>::Install::Files for easier interoperability
    with the Inline module.
  - Accompany the 'Inline' method with a 'deps' method in
    <package>::Install::Files in addition to the @deps package variable.
  - Make ExtUtils::Depends->load use the 'Inline' and 'deps' methods by
    default, falling back to the package variables if the methods are not
    defined.
  - Make the docs recommend the 'Inline' and 'deps' approach for creating
    <package>::Install::Files manually, without
    ExtUtils::Depends::save_config.
  0.309 Sat Aug  2 15:23:03 PDT 2014
  - Depends.pm: use $DLEXT instead of $SO for library filename extensions
  - MANIFEST: remove MYMETA.* files
  - use DynaLoader::mod2fname if available
  - Added Android support
  0.308 Sun May 18 16:22:11 PDT 2014
  - Fix win32 test failure in t/02_save_load.t (closes RT#95301)
  0.307 Mon Apr 28 22:04:38 PDT 2014
  - $Data::Dumper::Terse set to 1 broke save_config
  - Document API expected by ::load function
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.306
  - Fixed typo in RT queue URL; fixes RT#88960
  - Makefile.PL: converted to CPAN::Meta::Spec v2
  - Updated license in RPM spec file; closes RT#88196
  - Updated contact info and added git repo info to POD
  - Add comments for find_extra_libs method (closes RT#43900)
  - Fixed typo (closes RT#86572)
* Thu Jan 27 2011 vcizek@novell.com
- update to 0.304
  - More robust detection of gcc toolchains on Win32
  (Closes: RT#62455) (sisyphus).
  - Don't assume dlltool is called 'dlltool' on Win32+gcc. Ask Config.pm
  instead (Closes: RT#62455) (sisyphus).
* Fri Dec 10 2010 coolo@novell.com
- fix buildrequires
* Thu Dec  2 2010 anicka@suse.cz
- update to 0.303
  * Fix a race condition when running the tests in parallel.
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 0.302
  * Create import libraries if necessary to fix linking when gcc is used
  on MSWin32 (Strawberry Perl, for example).
* Wed Sep 10 2008 anicka@suse.cz
- update to 0.301
  * On Cygwin, link directly against the DLLs of dependencies.
  * Require perl 5.6.0.
* Wed Apr  2 2008 anicka@suse.cz
- update to 0.300
  - On MSWin32 and cygwin, find the link libraries of dependencies
  and put them into LIBS.
  - Add tests.
  - Correct typos in the documentation.
  - In get_makefile_vars, comment out the code that put the
  installed libraries into @OBJECT, which caused them to get
  deleted on realclean.
  - In Makefile.PL, don't use the bogus package "MAIN".
  - Remove debug spew.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul 29 2005 mjancar@suse.cz
- update to 0.205
* Tue Nov  2 2004 mcihar@suse.cz
- initial packaging
